scipy.sparse.construct
======================

.. automodule:: scipy.sparse.construct

   
   
   .. rubric:: Functions

   .. autosummary::
   
      bmat
      eye
      hstack
      identity
      kron
      kronsum
      rand
      spdiags
      upcast
      vstack
      warn
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      bsr_matrix
      coo_matrix
      csc_matrix
      csr_matrix
      dia_matrix
      lil_matrix
   
   

   
   
   